# NiLBS

## About

Implementation of [Neural Inverse Linear Blend Skinning](https://arxiv.org/pdf/2004.05980.pdf) extended to work in 3D.

## Installation

### Prerequisites 

The following packages are required.

1. [VPoser: Variational Human Pose Prior](https://github.com/nghorbani/human_body_prior)

2. [Trimesh](https://github.com/mikedh/trimesh)

3. [Tensorflow](https://github.com/tensorflow/tensorflow)

### Install the package

1. Clone the git repo using `git clone https://github.com/joemarch010/NiLBS.git`
 
2. Download the 'models' and 'data' folders [here](https://drive.google.com/drive/u/0/folders/1pjJ1MD_kWWAfOIpKtssHe_HvQw887JBT) 

3. Place the folders in the NiLBS directory with the 'train' and 'demo' folders.


## Running the demos

Code which demonstrates the usage of NiLBS can be found in the 'demo' folder. Running any of these scripts will open a pyglet window to show the output.
